@@ -11,10 +11,10 @@ use warnings;
 
 use lib qw(../lib);
 use experimental qw(signatures);
-use Math::AnyNum qw(tau bernfrac factorial);
+use Math::AnyNum qw(tau bernoulli factorial);
 
 sub zeta_2n($n) {
-    (-1)**($n + 1) * bernfrac(2 * $n) / factorial(2 * $n) * tau**(2 * $n) / 2;
+    (-1)**($n + 1) * bernoulli(2 * $n) / factorial(2 * $n) * tau**(2 * $n) / 2;
 }
 
 for my $i (1 .. 30) {
